Skip to content
GitLab
Explore
Sign in
Register
nexedi
cython
Repository
cython
Cython
Compiler
ExprNodes.py
Find file
Blame
History
Permalink
use PyObject_Call() instead of _CallObject() just as Python calls it...
· f669064a
Stefan Behnel
authored
Jan 14, 2008
use PyObject_Call() instead of _CallObject() just as Python calls it internally, speedup of about 5%
f669064a